@@ -1,4 +1,4 @@
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of logilab-common.
@@ -65,9 +65,6 @@ try:
 except ImportError:
     HAS_MX_DATETIME = False
 
-
-OPTPARSE_FORMAT_DEFAULT = sys.version_info >= (2, 4)
-
 from logilab.common.textutils import splitstrip
 
 def check_regexp(option, opt, value):
@@ -227,10 +224,7 @@ class Option(BaseOption):
     def process(self, opt, value, values, parser):
         # First, convert the value(s) to the right type.  Howl if any
         # value(s) are bogus.
-        try:
-            value = self.convert_value(opt, value)
-        except AttributeError: # py < 2.4
-            value = self.check_value(opt, value)
+        value = self.convert_value(opt, value)
         if self.type == 'named':
             existant = getattr(values, self.dest)
             if existant:
